Spyder plugin for **modelx**
============================

Spyder plugin to add custom consoles and widgets for
`modelx <https://github.com/fumitoh/spyder-modelx>`_ .

See `modelx site <https://docs.modelx.io>`_ .

Project information
-------------------
|license| |pypi version| |py version|

.. |license| image:: https://img.shields.io/pypi/l/spyder-modelx.svg
  :target: LICENSE.LESSER.txt
  :alt: License

.. |pypi version| image:: https://img.shields.io/pypi/v/spyder-modelx.svg
  :target: https://pypi.python.org/pypi/spyder-modelx
  :alt: Latest PyPI version

.. |py version| image:: https://img.shields.io/pypi/pyversions/spyder-modelx
    :target: https://pypi.org/project/spyder-modelx


Description
-----------
Spyder plugin for modelx.

Installation
------------

Using pip

`pip install spyder-modelx`

Anaconda users should manualy install `modelx`
and put `--no-deps` otpion for `spyder-modelx`:

`pip intasll modelx`

`pip intasll --no-deps spyer-modelx`

Usage
-----
See https://docs.modelx.io
